# py-shinylive-authentication

## Preliminary Release
- Documentation is scarse at this point. 
- For usage, see docstrings on the `src.shiny_auth.AuthProtocol` class methods.
- For examples, see code in:
  - `src_dev/app.py`
  - `src_dev/simple_security/`
  - `src_dev/restapi_security/`

## Install Test Dependencies
- `uv pip install -e '.[tests]'`